This function constructs the necessary data URLs for a given data set, version and polygon and downloads them for further processing with the mapme.biodiversity package.
get_gsw_time_series(years, version = "LATEST")A function that returns a character vector of file paths.
Numeric vector of years to process between 1984 and 2021.
Default: 1984:2021.
Version of the data set to process. Available options are
(VER1-0, VER2-0, VER3-0, VER4-0, VER5-0 and LATEST) Default:
LATEST. Choosing LATEST will result in the latest available version.
The available surface water classes for a given pixel are the following:
No Observation: It was not possible to determine whether a pixel was water (this may be the case for frozen areas or during the polar night in extreme latitudes).
Permanent Water: Water was detected in twelve months per year or in a combination of permanent and no observation.
Seasonal Water: Water and no water was detected.
No Water: No Water was detected.
Global Surface Water Explorer: https://global-surface-water.appspot.com/
Data Users Guide: https://storage.cloud.google.com/global-surface-water/downloads_ancillary/DataUsersGuidev2021.pdf
Research Article: https://www.nature.com/articles/nature20584